pub trait HashToString {
// Required methods
fn hash_to_string(&self) -> String;
fn as_hash(&self) -> u64;
}Expand description
Use the hash of this object for various purposes, such as generating a unique filename
Required Methods
Sourcefn hash_to_string(&self) -> String
fn hash_to_string(&self) -> String
get a string of the hash of this object; useful for things like filenames